@@ -49,6 +49,14 @@ class KeycloakEnvironment():
         self.keycloak_admin_auth_password = os.environ['KEYCLOAK_ADMIN_AUTH_PASSWORD'] if 'KEYCLOAK_ADMIN_AUTH_PASSWORD' in os.environ else self.defaultAdminAuthPassword
         self.keycloak_admin_auth_realm = os.environ['KEYCLOAK_ADMIN_AUTH_REALM'] if 'KEYCLOAK_ADMIN_AUTH_REALM' in os.environ else self.defaultAdminAuthRealm
         self.validate_certs = os.environ['VALIDATE_CERTS'] if 'VALIDATE_CERTS' in os.environ else self.defaultValidateCert
+        if self.keycloak_enabled:
+            self.kc = KeycloakAPI(auth_keycloak_url=self.keycloak_url,
+                         auth_client_id="admin-cli",
+                         auth_username=self.keycloak_admin_auth_user,
+                         auth_password=self.keycloak_admin_auth_password,
+                         auth_realm=self.keycloak_admin_auth_realm,
+                         auth_client_secret=None,
+                         validate_certs=self.validate_certs)
         
     def authenticateByServiceAccount(self, client_id=None, client_realm=None):
         headers = {}
@@ -56,17 +64,7 @@ class KeycloakEnvironment():
         realm = client_realm if client_realm is not None else self.keycloak_auth_realm
 
         if self.keycloak_enabled:
-            kc = KeycloakAPI(auth_keycloak_url=self.keycloak_url,
-                         auth_client_id="admin-cli",
-                         auth_username=self.keycloak_admin_auth_user,
-                         auth_password=self.keycloak_admin_auth_password,
-                         auth_realm=self.keycloak_admin_auth_realm,
-                         auth_client_secret=None,
-                         validate_certs=self.validate_certs)
-            keycloak_client = kc.get_client_by_clientid(client_id=client, realm=realm)
-            keycloak_auth_client_secret = kc.get_client_secret_by_id(keycloak_client["id"], realm=realm)
-            keycloak_auth_client_secret_value = keycloak_auth_client_secret['value'] if keycloak_auth_client_secret is not None and 'value' in keycloak_auth_client_secret else None
-            
+            keycloak_auth_client_secret_value = self.get_client_secret(client_id=client, realm=realm)
             headers = get_service_account_token(
                 base_url=self.keycloak_url,
                 auth_realm=self.keycloak_auth_realm,
@@ -79,17 +77,7 @@ class KeycloakEnvironment():
     def authenticateByUsernamePassword(self):
         headers = {}
         if self.keycloak_enabled:
-            kc = KeycloakAPI(auth_keycloak_url=self.keycloak_url,
-                         auth_client_id="admin-cli",
-                         auth_username=self.keycloak_admin_auth_user,
-                         auth_password=self.keycloak_admin_auth_password,
-                         auth_realm=self.keycloak_admin_auth_realm,
-                         auth_client_secret=None,
-                         validate_certs=self.validate_certs)
-            keycloak_client = kc.get_client_by_clientid(client_id=self.keycloak_auth_client_id, realm=self.keycloak_auth_realm)
-            keycloak_auth_client_secret = kc.get_client_secret_by_id(keycloak_client["id"], realm=self.keycloak_auth_realm)
-            keycloak_auth_client_secret_value = keycloak_auth_client_secret['value'] if keycloak_auth_client_secret is not None and 'value' in keycloak_auth_client_secret else None
-
+            keycloak_auth_client_secret_value = self.get_client_secret(client_id=self.keycloak_auth_client_id, realm=self.keycloak_auth_realm)
             headers = get_token(
                 base_url=self.keycloak_url,
                 validate_certs=self.validate_certs,
@@ -100,3 +88,19 @@ class KeycloakEnvironment():
                 client_secret=keycloak_auth_client_secret_value)
         self.headers = headers
         return headers
+
+    def get_token_url(self):
+        return self.kc.get_token_url(realm=self.keycloak_auth_realm)
+
+    def get_client_secret(self, client_id, realm=None):
+        if realm is None:
+            realm = self.keycloak_auth_realm
+        if self.keycloak_enabled:
+            keycloak_client = self.kc.get_client_by_clientid(client_id=client_id, realm=realm)
+            keycloak_auth_client_secret = self.kc.get_client_secret_by_id(keycloak_client["id"], realm=realm)
+            keycloak_auth_client_secret_value = keycloak_auth_client_secret['value'] if keycloak_auth_client_secret is not None and 'value' in keycloak_auth_client_secret else None
+            return keycloak_auth_client_secret_value
+        return None
+
+        
+
